@@ -1,15 +1,3 @@
-#-----------------------------------------------------------------------------
-# Name:        asamacros.py
-# Purpose:     Macros for processing 1D SAXS data (line focus, Hecus-ASA)
-#
-# Author:      Andras Wacha
-#
-# Created:     2010/02/22
-# RCS-ID:      $Id: asamacros.py $
-# Copyright:   (c) 2010
-# Licence:     GPLv2
-#-----------------------------------------------------------------------------
-
 import numpy as np
 import pylab
 import fitting
@@ -439,7 +427,7 @@ def directdesmearflat(pix,Intensity,Error,beamprofile_or_mat,L,pixelsize,NMC=0):
         edesm+=(idesm-id1)**2
     return idesm,np.sqrt(edesm)/(NMC-1),beamprofile_or_mat
 
-def desmearflat(x,Intensity,Error,beamprofile_or_mat,smoothing,L,pixelsize,title='',NMC=1000):
+def desmearflat(x,Intensity,Error,beamprofile_or_mat,smoothing,L,pixelsize,title='',NMC=10):
     """De-smear scattering curves (flat detector)
     
     Inputs:
@@ -465,8 +453,9 @@ def desmearflat(x,Intensity,Error,beamprofile_or_mat,smoothing,L,pixelsize,title
                                               beamprofile_or_mat['x'],
                                               beamprofile_or_mat['y'],L)
     def cbfunc(sm,ysm,axes,matrix=beamprofile_or_mat):
-        Idesm,mat=directdesmearflat(x,ysm,Error,beamprofile_or_mat,L,pixelsize,NMC=0)
-        matrix['mat']=mat
+        Idesm,mat=directdesmearflat(x,ysm,Error,matrix,L,pixelsize,NMC=0)
+        if type(matrix)==type({}):
+            matrix['mat']=mat # the smearing matrix won't change during the iterations, better fix it to avoid re-calculation
         axes.plot(x,Idesm)
         axes.set_title(title)
     sm,ysm=guitools.testsmoothing(x,Intensity,smoothing,
